==> flink-kubernetes-operator-1.4.0-src.tgz: flink-kubernetes-operator-1.4.0/flink-kubernetes-operator-autoscaler/src/main/java/org/apache/flink/kubernetes/operator/autoscaler/JobAutoscalerFactoryImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.kubernetes.operator.autoscaler;

import org.apache.flink.kubernetes.operator.reconciler.deployment.JobAutoScaler;
import org.apache.flink.kubernetes.operator.reconciler.deployment.JobAutoScalerFactory;
import org.apache.flink.kubernetes.operator.utils.EventRecorder;

import com.google.auto.service.AutoService;
import io.fabric8.kubernetes.client.KubernetesClient;

/**
 * Factory for loading JobAutoScalerImpl included in this module. This class will be dynamically
 * instantiated by the main operator module.
 */
@AutoService(JobAutoScalerFactory.class)
public class JobAutoscalerFactoryImpl implements JobAutoScalerFactory {
    @Override
    public JobAutoScaler create(KubernetesClient kubernetesClient, EventRecorder eventRecorder) {
        return new JobAutoScalerImpl(
                kubernetesClient,
                new RestApiMetricsCollector(),
                new ScalingMetricEvaluator(),
                new ScalingExecutor(kubernetesClient, eventRecorder));
    }
}

==> flink-kubernetes-operator-1.5.0-src.tgz: flink-kubernetes-operator-1.5.0/flink-kubernetes-operator-autoscaler/src/main/java/org/apache/flink/kubernetes/operator/autoscaler/JobAutoscalerFactoryImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.kubernetes.operator.autoscaler;

import org.apache.flink.kubernetes.operator.reconciler.deployment.JobAutoScaler;
import org.apache.flink.kubernetes.operator.reconciler.deployment.JobAutoScalerFactory;
import org.apache.flink.kubernetes.operator.utils.EventRecorder;

import com.google.auto.service.AutoService;
import io.fabric8.kubernetes.client.KubernetesClient;

/**
 * Factory for loading JobAutoScalerImpl included in this module. This class will be dynamically
 * instantiated by the main operator module.
 */
@AutoService(JobAutoScalerFactory.class)
public class JobAutoscalerFactoryImpl implements JobAutoScalerFactory {
    @Override
    public JobAutoScaler create(KubernetesClient kubernetesClient, EventRecorder eventRecorder) {
        return new JobAutoScalerImpl(
                kubernetesClient,
                new RestApiMetricsCollector(),
                new ScalingMetricEvaluator(),
                new ScalingExecutor(kubernetesClient, eventRecorder),
                eventRecorder);
    }
}
